@@ -2,18 +2,19 @@
 #
 # Samizdat version test
 #
-#   Copyright (c) 2002-2004  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2005  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
 #   the GNU General Public License version 2 or later.
 #
+# vim: et sw=2 sts=2 ts=8 tw=0
 
 require 'test/unit'
-require 'samizdat'
+require 'samizdat/engine'
 
 class TC_Version < Test::Unit::TestCase
-    def test_version
-        assert_equal '0.5.4', SAMIZDAT_VERSION.split('.')[0..2].join('.')
-    end
+  def test_version
+    assert_equal '0.5.5', SAMIZDAT_VERSION.split('.')[0..2].join('.')
+  end
 end
